@@ -19,7 +19,11 @@ from mypy_boto3_builder.constants import (
 from mypy_boto3_builder.jinja_manager import JinjaManager
 from mypy_boto3_builder.logger import get_logger
 from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
-from mypy_boto3_builder.utils.strings import get_anchor_link
+from mypy_boto3_builder.utils.strings import (
+    get_anchor_link,
+    get_botocore_class_name,
+    get_min_build_version,
+)
 from mypy_boto3_builder.writers.processors import (
     process_boto3_stubs,
     process_boto3_stubs_docs,
@@ -40,16 +44,14 @@ def get_available_service_names(session: Session) -> List[ServiceName]:
     Returns:
         A list of supported services.
     """
-    logger = get_logger()
     available_services = session.get_available_services()
+    botocore_session = session._session  # type: ignore
     result = []
-    for available_service in available_services:
-        try:
-            service_name = ServiceNameCatalog.find(available_service)
-        except ValueError:
-            logger.info(f"Service {available_service} is not fully supported.")
-            continue
-
+    for name in available_services:
+        service_data = botocore_session.get_service_data(name)
+        metadata = service_data["metadata"]
+        class_name = get_botocore_class_name(metadata)
+        service_name = ServiceNameCatalog.add(name, class_name)
         result.append(service_name)
     return result
 
@@ -66,18 +68,26 @@ def main() -> None:
     available_service_names_set = {i.name for i in available_service_names}
     service_names: List[ServiceName] = []
 
-    for service_name in args.service_names or available_service_names:
-        if service_name.name not in available_service_names_set:
-            logger.info(f"Service {service_name.name} is not provided by boto3, skipping.")
+    logger.info(f"{len(available_service_names_set)} supported boto3 services discovered")
+    if args.list_services:
+        for service_name in available_service_names:
+            print(
+                f"- {service_name.name} : {service_name.class_name} {service_name.boto3_doc_link}"
+            )
+        return
+
+    selected_service_names = args.service_names or [i.name for i in available_service_names]
+
+    for service_name_str in selected_service_names:
+        if service_name_str not in available_service_names_set:
+            logger.info(f"Service {service_name_str} is not provided by boto3, skipping")
             continue
 
+        service_name = ServiceNameCatalog.find(service_name_str)
         service_names.append(service_name)
 
-    if not args.generate_docs:
-        for service_name in service_names:
-            service_name.boto3_version = boto3_version
-
     build_version = args.build_version or boto3_version
+    min_build_version = get_min_build_version(build_version)
     botocore_build_version = botocore_version
     if args.build_version and ".post" in args.build_version:
         post_release = args.build_version.split(".post")[-1]
@@ -89,6 +99,7 @@ def main() -> None:
         boto3_version=boto3_version,
         botocore_version=botocore_version,
         build_version=build_version,
+        min_build_version=min_build_version,
         botocore_build_version=botocore_build_version,
         builder_version=args.builder_version,
         get_anchor_link=get_anchor_link,
@@ -121,12 +132,14 @@ def generate_stubs(args: Namespace, service_names: List[ServiceName], session: S
         for index, service_name in enumerate(service_names):
             current_str = f"{{:0{len(total_str)}}}".format(index + 1)
             logger.info(f"[{current_str}/{total_str}] Generating {service_name.module_name} module")
+            service_name.boto3_version = boto3_version
             process_service(
                 session=session,
                 output_path=args.output_path,
                 service_name=service_name,
                 generate_setup=not args.installed,
             )
+            service_name.boto3_version = ServiceName.LATEST
 
     if not args.skip_master:
         if not args.installed:
