@@ -24,7 +24,7 @@ from mypy_boto3_builder.service_name import ServiceName, ServiceNameCatalog
 from mypy_boto3_builder.structures.argument import Argument
 from mypy_boto3_builder.structures.method import Method
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
-from mypy_boto3_builder.type_annotations.internal_import import AliasInternalImport
+from mypy_boto3_builder.type_annotations.internal_import import AliasInternalImport, InternalImport
 from mypy_boto3_builder.type_annotations.type import Type
 from mypy_boto3_builder.type_annotations.type_class import TypeClass
 from mypy_boto3_builder.type_annotations.type_constant import TypeConstant
@@ -467,12 +467,11 @@ class ShapeParser:
 
         return_type: FakeAnnotation = Type.none
         if operation_shape.output_shape is not None:
-            return_type = TypeSubscript(
-                Type.Iterator,
-                [
-                    self._parse_return_type("Paginator", "paginate", operation_shape.output_shape),
-                ],
+            page_iterator_import = InternalImport("_PageIterator", stringify=False)
+            return_item = self._parse_return_type(
+                "Paginator", "paginate", operation_shape.output_shape
             )
+            return_type = TypeSubscript(page_iterator_import, [return_item])
 
         return Method("paginate", arguments, return_type)
 
